@@ -41,6 +41,12 @@ class DiffType(str, Enum):
     UPDATED = "updated"
 
 
+class ScanType(str, Enum):
+    SOCKET = "socket"
+    SOCKET_TIER1 = "socket_tier1"
+    SOCKET_BASICS = "socket_basics"
+
+
 @dataclass(kw_only=True)
 class SocketPURL:
     type: SocketPURL_Type
@@ -99,6 +105,7 @@ class FullScanParams:
     make_default_branch: Optional[bool] = None
     set_as_pending_head: Optional[bool] = None
     tmp: Optional[bool] = None
+    scan_type: Optional[ScanType] = None
 
     def __getitem__(self, key):
         return getattr(self, key)
@@ -109,6 +116,7 @@ class FullScanParams:
     @classmethod
     def from_dict(cls, data: dict) -> "FullScanParams":
         integration_type = data.get("integration_type")
+        scan_type = data.get("scan_type")
         return cls(
             repo=data["repo"],
             org_slug=data.get("org_slug"),
@@ -122,6 +130,7 @@ class FullScanParams:
             make_default_branch=data.get("make_default_branch"),
             set_as_pending_head=data.get("set_as_pending_head"),
             tmp=data.get("tmp"),
+            scan_type=ScanType(scan_type) if scan_type is not None else None,
         )
 
 
@@ -789,6 +798,14 @@ class FullScans:
         org_slug = str(params.org_slug)
         params_dict = params.to_dict()
         params_dict.pop("org_slug")
+        # Remove pull_request param if it's None, 0, or not an integer
+        if hasattr(params, 'pull_request') and (
+            params.pull_request is None or 
+            not isinstance(params.pull_request, int) or 
+            params.pull_request == 0
+        ):
+            print("Removing pull_request param from FullScanParams as it is None, 0, or not an integer")
+            params_dict.pop("pull_request")
         params_arg = urllib.parse.urlencode(params_dict)
         path = "orgs/" + org_slug + "/full-scans?" + str(params_arg)
 
@@ -1070,4 +1087,4 @@ class FullScans:
 
         error_message = response.json().get("error", {}).get("message", "Unknown error") if response.text else "Unknown error"
         log.error(f"Error downloading tar files: {response.status_code}, message: {error_message}")
-        return b""
\ No newline at end of file
+        return b""
